==> haskell-email-validate-2.3.2.15-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.15
visibility:           public
id:                   email-validate-2.3.2.15-Imi35DjRoHBLrOvnx7ZS7F
key:                  email-validate-2.3.2.15-Imi35DjRoHBLrOvnx7ZS7F
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  ddc3182e4edf03140fd75915b7dd43a7
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.0.1/site-local/email-validate-2.3.2.15
library-dirs:         /usr/lib/ghc-9.0.1/site-local/email-validate-2.3.2.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/email-validate-2.3.2.15
hs-libraries:         HSemail-validate-2.3.2.15-Imi35DjRoHBLrOvnx7ZS7F
depends:
    attoparsec-0.14.1-2NPvvgp5QbjKeCRmapAgpC base-4.15.0.0
    bytestring-0.10.12.1 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.15-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 email-validate
version:              2.3.2.15
visibility:           public
id:                   email-validate-2.3.2.15-7sVJfpsYCWcBCZw1YNco94
key:                  email-validate-2.3.2.15-7sVJfpsYCWcBCZw1YNco94
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  c6655fe2db97813713353bc36bbe0fe5
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.0.1/site-local/email-validate-2.3.2.15
library-dirs:         /usr/lib/ghc-9.0.1/site-local/email-validate-2.3.2.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/email-validate-2.3.2.15
hs-libraries:         HSemail-validate-2.3.2.15-7sVJfpsYCWcBCZw1YNco94
depends:
    attoparsec-0.14.1-B8P567zH1pOF107V9enGUK base-4.15.0.0
    bytestring-0.10.12.1 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
